@@ -1,4 +1,4 @@
-from .commons import Column, Parameters
+from .commons import Column, Parameters, TOL
 from .column_generation import column_generation
 from .branching_scheme import greedy, limited_discrepancy_search
 
@@ -8,4 +8,5 @@ __all__ = [
     'column_generation',
     'greedy',
     'limited_discrepancy_search',
+    'TOL',
 ]
